#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-get-opt
version:              0.5
visibility:           public
id:                   simple-get-opt-0.5-CgQJuEH7oNQCTS5en5DsQO
key:                  simple-get-opt-0.5-CgQJuEH7oNQCTS5en5DsQO
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A simple library for processing command-line options.
description:
    A simple library for processing command-line options.
    The library captures a common usage pattern of the GetOpt module
    form the standard libraries.

category:             Development
abi:                  af0517dcd3d05f3c3daf425850837d0e
exposed:              True
exposed-modules:      SimpleGetOpt
import-dirs:          /usr/lib/ghc-9.6.6/site-local/simple-get-opt-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/simple-get-opt-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/simple-get-opt-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-get-opt
hs-libraries:         HSsimple-get-opt-0.5-CgQJuEH7oNQCTS5en5DsQO
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-simple-get-opt/html/simple-get-opt.haddock

haddock-html:         /usr/share/doc/haskell-simple-get-opt/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

